==> eam-wshub-proxyclient-11.6-1-sources.jar: net/datastream/schemas/mp_fields/YEARLYINFLATIONPERCENTAGEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour YEARLYINFLATIONPERCENTAGEID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="YEARLYINFLATIONPERCENTAGEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}YEAR"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}INFLATIONCOUNTRYID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CURRENCYID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "YEARLYINFLATIONPERCENTAGEID_Type", propOrder = {
    "year",
    "inflationcountryid",
    "currencyid"
})
public class YEARLYINFLATIONPERCENTAGEID_Type {

    @XmlElement(name = "YEAR")
    protected long year;
    @XmlElement(name = "INFLATIONCOUNTRYID", required = true)
    protected USERDEFINEDCODEID_Type inflationcountryid;
    @XmlElement(name = "CURRENCYID", required = true)
    protected CURRENCYID_Type currencyid;

    /**
     * Obtient la valeur de la propriété year.
     * 
     */
    public long getYEAR() {
        return year;
    }

    /**
     * Définit la valeur de la propriété year.
     * 
     */
    public void setYEAR(long value) {
        this.year = value;
    }

    /**
     * Obtient la valeur de la propriété inflationcountryid.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public USERDEFINEDCODEID_Type getINFLATIONCOUNTRYID() {
        return inflationcountryid;
    }

    /**
     * Définit la valeur de la propriété inflationcountryid.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public void setINFLATIONCOUNTRYID(USERDEFINEDCODEID_Type value) {
        this.inflationcountryid = value;
    }

    /**
     * Obtient la valeur de la propriété currencyid.
     * 
     * @return
     *     possible object is
     *     {@link CURRENCYID_Type }
     *     
     */
    public CURRENCYID_Type getCURRENCYID() {
        return currencyid;
    }

    /**
     * Définit la valeur de la propriété currencyid.
     * 
     * @param value
     *     allowed object is
     *     {@link CURRENCYID_Type }
     *     
     */
    public void setCURRENCYID(CURRENCYID_Type value) {
        this.currencyid = value;
    }

}

==> eam-wshub-proxyclient-12.0-sources.jar: net/datastream/schemas/mp_fields/YEARLYINFLATIONPERCENTAGEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for YEARLYINFLATIONPERCENTAGEID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="YEARLYINFLATIONPERCENTAGEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}YEAR"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}INFLATIONCOUNTRYID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CURRENCYID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "YEARLYINFLATIONPERCENTAGEID_Type", propOrder = {
    "year",
    "inflationcountryid",
    "currencyid"
})
public class YEARLYINFLATIONPERCENTAGEID_Type {

    @XmlElement(name = "YEAR")
    protected long year;
    @XmlElement(name = "INFLATIONCOUNTRYID", required = true)
    protected USERDEFINEDCODEID_Type inflationcountryid;
    @XmlElement(name = "CURRENCYID", required = true)
    protected CURRENCYID_Type currencyid;

    /**
     * Gets the value of the year property.
     * 
     */
    public long getYEAR() {
        return year;
    }

    /**
     * Sets the value of the year property.
     * 
     */
    public void setYEAR(long value) {
        this.year = value;
    }

    /**
     * Gets the value of the inflationcountryid property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public USERDEFINEDCODEID_Type getINFLATIONCOUNTRYID() {
        return inflationcountryid;
    }

    /**
     * Sets the value of the inflationcountryid property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public void setINFLATIONCOUNTRYID(USERDEFINEDCODEID_Type value) {
        this.inflationcountryid = value;
    }

    /**
     * Gets the value of the currencyid property.
     * 
     * @return
     *     possible object is
     *     {@link CURRENCYID_Type }
     *     
     */
    public CURRENCYID_Type getCURRENCYID() {
        return currencyid;
    }

    /**
     * Sets the value of the currencyid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CURRENCYID_Type }
     *     
     */
    public void setCURRENCYID(CURRENCYID_Type value) {
        this.currencyid = value;
    }

}
